@@ -169,7 +169,11 @@ trajCluster <- function(traj, method = "Euclid", n.cluster = 5,
       z <- matrix(0, nrow = n, ncol = len)
       res <- matrix(0, nrow = len, ncol = len)
       
-      res <- .Call(method, x, y, res)
+      if (method == "distEuclid")
+        res <- .Call("distEuclid", x, y, res)
+      
+      if (method == "distAngle")
+        res <- .Call("distAngle", x, y, res)
       
       res[is.na(res)] <- 0 ## possible for some to be NA if trajectory does not move between two hours?
       
@@ -212,7 +216,7 @@ trajCluster <- function(traj, method = "Euclid", n.cluster = 5,
       
       agg <- select_(traj, "lat", "lon", "date", "cluster", "hour.inc", type) %>% 
         group_by_(., "cluster", "hour.inc", type) %>% 
-        summarise_each(funs(mean))
+        summarise_all(funs(mean))
       
       # the data frame we want to return before it is transformed
       resRtn <- agg
